@@ -162,17 +162,20 @@ class Validator:
 
   def _validate_type(self, arg, value, specification):
     arg_type = [aarg["type"] for aarg in specification["args"] if aarg["name"] == arg][0]
-    if arg_type != "any":
+    required = [aarg["required"] for aarg in specification["args"] if aarg["name"] == arg][0]
+    if required or value is not None:
       try:
-        arg_type = getattr(builtins, arg_type)
-        if not isinstance(value, arg_type):
+        allowed_types = arg_type if isinstance(arg_type, list) else [arg_type]
+        allow = [isinstance(value, getattr(builtins, allowed))
+                for allowed in allowed_types]
+        if not any(allow):
           msg = {"type": "BadArgTypeError",
-                 "message": f"Expected type {arg_type} / received {type(value)} for {arg}."}
+                "message": f"Expected type one of {allowed_types} / received {type(value)} for {arg}."}
           logging.critical(f"[{msg['type']}] {msg['message']}")
           raise LaboroError(f"[{msg['type']}] {msg['message']}")
       except AttributeError as err:
         msg = {"type": "UnknownTypeError",
-               "message": f"Unknown type '{arg_type}' for argument {arg}."}
+              "message": f"Unknown type '{arg_type}' for argument {arg}."}
         logging.critical(f"[{msg['type']}] {msg['message']}")
         raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
 
