@@ -29,8 +29,8 @@ class Workflow:
 
       cfg_mgr = CfgMgr(main_config="/etc/laboro/laboro.yml")
       context = Context(logger=LogMgr(Vault()), config_mgr=cfg_mgr)
-      logging.getLogger().log_section("LABORO", "Bootstrapping")
-      logging.getLogger().vault.clear()
+      logging.getLogger("laboro.main").log_section("LABORO", "Bootstrapping")
+      logging.getLogger("laboro.main").vault.clear()
       cfg_mgr.workflow_config = "my_workflow.yml"
       workflow = cfg_mgr.workflow_config
       with Workflow(context=context, **workflow) as wkf:
@@ -56,4 +56,4 @@ class Workflow:
     for wkf_step in self.steps:
       with Step(self.ctx, **wkf_step) as step:
         step.run()
-    logging.getLogger().log_line()
+    logging.getLogger("laboro.main").log_line()
